@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-04-25'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2015-06-07'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -246,9 +246,9 @@ sub complete_program {
 $SPEC{complete_file} = {
     v => 1.1,
     summary => 'Complete file and directory from local filesystem',
-    args_groups => [
-        {rel=>'one_of', args=>[qw/filter file_regex_filter/]},
-    ],
+    args_rels => {
+        choose_one => [qw/filter file_regex_filter/],
+    },
     args => {
         word => {
             schema  => [str=>{default=>''}],
@@ -553,7 +553,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.29 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-25.
+This document describes version 0.30 of Complete::Util (from Perl distribution Complete-Util), released on 2015-06-07.
 
 =head1 DESCRIPTION
 
